pub struct DenseLayer {
pub(crate) inner: DenseLayer,
}Fields
inner: DenseLayerImplementations
Sourceimpl DenseLayer
impl DenseLayer
pub(crate) fn new( n_inputs: usize, n_neurons: usize, length: usize, seed: u64, ) -> Self
pub(crate) fn get_weights(&self) -> Vec<Vec<f64>>
pub(crate) fn set_weights(&mut self, weights: Vec<Vec<f64>>) -> PyResult<()>
pub(crate) fn refresh_packed_weights(&mut self)
pub(crate) fn forward( &self, input_values: Vec<f64>, seed: u64, ) -> PyResult<Vec<f64>>
pub(crate) fn forward_fast( &self, input_values: Vec<f64>, seed: u64, ) -> PyResult<Vec<f64>>
Sourcepub(crate) fn forward_numpy<'py>(
&self,
py: Python<'py>,
input_values: PyReadonlyArray1<'py, f64>,
seed: u64,
) -> PyResult<Bound<'py, PyArray1<f64>>>
pub(crate) fn forward_numpy<'py>( &self, py: Python<'py>, input_values: PyReadonlyArray1<'py, f64>, seed: u64, ) -> PyResult<Bound<'py, PyArray1<f64>>>
Dense forward accepting numpy input and returning numpy output.
This performs parallel encoding + parallel compute in one FFI call.
Sourcepub(crate) fn forward_batch_numpy<'py>(
&self,
py: Python<'py>,
inputs: PyReadonlyArray2<'py, f64>,
seed: u64,
) -> PyResult<Bound<'py, PyArray2<f64>>>
pub(crate) fn forward_batch_numpy<'py>( &self, py: Python<'py>, inputs: PyReadonlyArray2<'py, f64>, seed: u64, ) -> PyResult<Bound<'py, PyArray2<f64>>>
Dense forward for a batch of input samples in one FFI call.
inputs must be a contiguous float64 array of shape (n_samples, n_inputs).
Returns float64 array of shape (n_samples, n_neurons).
Sourcepub(crate) fn forward_prepacked(
&self,
packed_inputs: &Bound<'_, PyAny>,
) -> PyResult<Vec<f64>>
pub(crate) fn forward_prepacked( &self, packed_inputs: &Bound<'_, PyAny>, ) -> PyResult<Vec<f64>>
Forward pass with pre-packed input bitstreams.
Accepts either:
- 2-D numpy array of dtype uint64 with shape (n_inputs, words)
- list[list[int]]
Sourcepub(crate) fn forward_prepacked_numpy<'py>(
&self,
py: Python<'py>,
packed_inputs: PyReadonlyArray2<'py, u64>,
) -> PyResult<Bound<'py, PyArray1<f64>>>
pub(crate) fn forward_prepacked_numpy<'py>( &self, py: Python<'py>, packed_inputs: PyReadonlyArray2<'py, u64>, ) -> PyResult<Bound<'py, PyArray1<f64>>>
Dense forward with pre-packed numpy 2-D input (true zero-copy).
Accepts a contiguous numpy uint64 array of shape (n_inputs, words).
This avoids all row-copying that the forward_prepacked method does.